/*========================================================================
     "gpop4thf"  Gaussian output post processor 4
        - calculate thermodynamic functions

             Copyright (c) 2002-2005 by A. Miyoshi, Univ. Tokyo
                                     created: Dec.  28, 2004
                                      edited: Jan.  13, 2005
--------------------------------------------------------------------------
 usage: gpop4thf basename[.gpo/.tst] [temperat-file]
--------------------------------------------------------------------------
 - The 'file' must be .gpo or .tst file.
 - Keywords allowed in the temperat-file (with any extension) are:
    tempRange Tstart(double) Tend(double) Tstep(double)
    tempList T1(double) T2(double) ...
 - Default temperatures are 300 to 1500 K with 100 K step.
========================================================================*/

#include "gpoplibt.h"

/*===== main routine ===================================================*/

int main(int argc, char *argv[]) {
  int useTempFile = false;
  string flname, basfln, extfln, tprfln, csvfln;
  ofstream ouf;
  molPropTST mptst;
  jobInfos jbinf;
  molecGeom molc;
  freqTable frtab;
  modInfoTST miTST;
  tempList temperat;
  resMolTherm rmth;

  if ((argc < 2) || (argc > 3)) {
    cout << "usage: gpop4thf basename[.gpo/.tst] [temperat-file]\n";
    return 1;
  }
  flname = argv[1]; basfln = getBasePart(flname);
  extfln = getExtPart(flname); strAllToLower(extfln);
  if (extfln == "") { extfln = "gpo"; }
  if (argc == 3) { tprfln = argv[2]; useTempFile = true; }
  if (extfln == "tst") {
    if (mptst.readFromTST(basfln) == ERRE)
      { cout << "failed to read [" << flname << "].\n"; return 1; }
  } else if (extfln == "gpo") {
    if (readGpo(basfln, jbinf, molc, frtab, miTST) == ERRE)
      { cout << "failed to read [" << flname << "].\n"; return 1; }
    mptst.setFrom(basfln, jbinf, molc, frtab, miTST);
  } else { cout << "invalid file name.\n"; return 1; }
  if (useTempFile) {
    if (temperat.readFrom(tprfln) == ERRE)
      { cout << "failed reading [" << tprfln << "].\n"; return 1; }
  }

  rmth = mptst.getMolTherm(temperat);
  csvfln = basfln + ".csv";
  ouf.open(csvfln.c_str());
  if (!ouf) { cout << "failed to open [" << csvfln << "].\n"; return 1; }
  rmth.printHeadCSV(ouf); rmth.ref.printCSV(ouf);
  rmth.printHeadCSVs(ouf); rmth.printCSVsubtH(ouf);
  ouf.close();
  return 0;
}

