/*========================================================================
     "gpop5vib"  Gaussian output post processor 5
        - create animation file (for FreeWheel) of vibrational modes

             Copyright (c) 2002-2005 by A. Miyoshi, Univ. Tokyo
                                     created: Sept.  2, 2004
                                      edited: Jan.  13, 2005
--------------------------------------------------------------------------
 usage: gpop5vib basename [ext]
--------------------------------------------------------------------------
 - Read basename.gpo, create animation files named basename_mXXX.ext,
    where XXX is the mode number, and 'ext' is the extension specified
    in the command line or 'log' (default).
--------------------------------------------------------------------------
 [Example]
 % gpop5vib ethylene
  - read ethylene.gpo, create ethylene_m001.log, ethylene_m002.log, etc.
========================================================================*/

#include "gpoplibc.h"

/*===== main function ==================================================*/

int main(int argc, char *argv[]) {
  int ifrq, iang, dang = 5;
  double devf;
  string basfln, anofln, extaf = "log";
  ofstream ouf;
  jobInfos jbinf;
  molecGeom molc;
  freqTable frtab;
  geomInfo geovar;

  if ((argc < 2) || (argc > 3))
    { cout << "usage: gpop5vib basename [ext]\n"; return 1; }
  basfln = argv[1];
  if (argc == 3) { extaf = argv[2]; }

  // --- read in gpop (.gpo) file
  if (readGpo(basfln, jbinf, molc, frtab) == ERRE) { return 1; }

  // --- write animation files
  for (ifrq = 0; ifrq < molc.nVibm; ifrq++) {
    anofln = basfln + "_m" + format(ifrq + 1, 3, '0') + "." + extaf;
    ouf.clear(); ouf.open(anofln.c_str());
    if (!ouf) { cout << "Error opening output.\n"; return 0; }
    ouf << " #\n ---\n ---\n\n";
    for (iang = 0; iang <= 360; iang += dang) {
      devf = sin(iang / 180. * M_PI);
      geovar = molc.geom + (frtab[ifrq].nrm * devf);
      geovar.outFWformat(ouf);
    }
    ouf.close();
  }

  return 0;
}

