#=========================================================================
#    This is a part of "gpop" - Gaussian output post processor
#            Copyright (c) 2002-2006 by A. Miyoshi, Univ. Tokyo
#=========================================================================
# --- make gpop - Gaussian output post processor ---------------------
# gpop1scf: read Gaussian SCF-freq job output and create a .gpo file
# gpop3atm: create .gpo data for atomic species
# gpop3tst: modification of .gpo data for thermo and TST calculations
# gpop4thf: calculate thermodynamic functions
# gpop5vib: create animation file (for FreeWheel) of vibrational modes
# gpop6irt: calculate reduced moment of inertia of a internal rotor
# tstrate: TST rate constant and equilibrium const. calculation
# --------------------------------------------------------------------
# * compilation of LAPACK is required only when LAPACK/BLAS
#  does not present on the system
# --------------------------------------------------------------------

# ----- C++ and Fortran compilers ----------------
#  Unix (Solaris)                   .. CC,  f77
#  GNU compiler (Linux, Cygwin)     .. g++, g77
#  GNU compiler (Djgpp)             .. gpp, g77
#  Intel compilers
#       for Linux v.7.1 or earlier
#                             32bit .. icc, ifc
#                             64bit .. ecc, efc
#       for Linux v.8.0 or later
#                     both 32/64bit .. icc, ifort
#       for Windows                 .. icl, ifort
# ----- optimization flags -----------------------
#  Intel compilers for Windows      .. -O2
#  Others                           .. -O
# ------------------------------------------------

#CPCMP = CC -O
#CPCMP = g++ -O
#CPCMP = gpp -O
#CPCMP = icc -O
CPCMP = ecc -O
#CPCMP = icl -O2

#F7CMP = f77 -O
#F7CMP = g77 -O
#F7CMP = ifc -O
F7CMP = efc -O
#F7CMP = ifort -O
#F7CMP = ifort -O2

#--- LAPACK/BLAS file ------------------------------
# to build a part of LAPACK/BLAS:
#  Intel compiler (Windows)  .. lapack_dsyev.lib
#  all other                 .. lapack_dsyev.a
# use pre-build LAPACK/BLAS: .. (null)
#---------------------------------------------------
FLPKSE = lapack_dsyev.a
#FLPKSE = lapack_dsyev.lib
#FLPKSE =

#--- Fortran library to build LAPACK/BLAS --------------------------------
# NOT required when FLPKSE = (null)
#  Unix (Solaris)                     .. -lfsu -lsunmath
#  GNU compiler                       .. -lg2c
#  Intel compiler (linux ver <= 7.1)  .. -lF90 -lIEPCF90
#  Intel compiler (linux ver == 8.x)  .. -L/opt/intel_fc_80/lib -lifcore
#  Intel compiler (linux ver == 9.x)  .. -L/opt/intel/fc/9.0/lib -lifcore
#  Intel compiler (Windows)           .. (null)
#-------------------------------------------------------------------------
#LLAPCK = -lfsu -lsunmath
#LLAPCK = -lg2c
LLAPCK = -lF90 -lIEPCF90
#LLAPCK = -L/opt/intel_fc_80/lib -lifcore
#LLAPCK = -L/opt/intel/fc/9.0/lib -lifcore
#LLAPCK =

#--- Linker option to link pre-build LAPACK/BLAS -----------------
# ONLY required when FLPKSE = (null)
#  linux g77-built      .. -llapack -lblas -lg2c
#  intel MKL7 (32bit) .. -L/opt/intel/mkl70/lib/32
#                        -lmkl_ia32 -lguide -lpthread
#  intel MKL7 (64bit) .. -L/opt/intel/mkl70/lib/64
#                        -lmkl_lapack -lmkl_ipf -lguide -lpthread
#-----------------------------------------------------------------
#LLAPCK = -llapack -lblas -lg2c
#LLAPCK = -L/opt/intel/mkl70/lib/32 -lmkl_ia32 -lguide -lpthread
#LLAPCK = -L/opt/intel/mkl70/lib/64 -lmkl_lapack -lmkl_ipf -lguide -lpthread

#--- 'remove' command ------------------------------
RM = rm -f
#RM = del

#--- file name extension of object files -----------
XOBJ = o
#XOBJ = obj

#--- temporary file other than object file ---------
# (needed ONLY for Djgpp)
#TMPF = gpop1scf gpop3atm gpop3tst gpop4thf gpop5vib gpop6irt gpop6mrt gpop7ctr tstrate introt
TMPF =

#===== no need to edit below in usual circumstances ======================

LIBOBJ = gpoplibc.$(XOBJ) gpoplibf.$(XOBJ) $(FLPKSE)
LIBROBJ = gpoplibr.$(XOBJ) $(LIBOBJ)
LIBTOBJ = gpoplibt.$(XOBJ) $(LIBROBJ)
HEADS = gpoplibc.h gpoplibf.h
HEADSR = gpoplibr.h $(HEADS)
HEADST = gpoplibt.h $(HEADSR)

all: gpop1scf gpop3atm gpop3tst gpop4thf gpop5vib \
     gpop6irt gpop6mrt tstrate introt

gpop1scf : gpop1scf.$(XOBJ) $(LIBOBJ)
	$(CPCMP) gpop1scf.$(XOBJ) $(LIBOBJ) $(LLAPCK) -o gpop1scf

gpop3atm : gpop3atm.$(XOBJ) $(LIBTOBJ)
	$(CPCMP) gpop3atm.$(XOBJ) $(LIBTOBJ) $(LLAPCK) -o gpop3atm

gpop3tst : gpop3tst.$(XOBJ) $(LIBTOBJ)
	$(CPCMP) gpop3tst.$(XOBJ) $(LIBTOBJ) $(LLAPCK) -o gpop3tst

gpop4thf : gpop4thf.$(XOBJ) $(LIBTOBJ)
	$(CPCMP) gpop4thf.$(XOBJ) $(LIBTOBJ) $(LLAPCK) -o gpop4thf

gpop5vib : gpop5vib.$(XOBJ) $(LIBOBJ)
	$(CPCMP) gpop5vib.$(XOBJ) $(LIBOBJ) $(LLAPCK) -o gpop5vib

gpop6irt : gpop6irt.$(XOBJ) $(LIBOBJ)
	$(CPCMP) gpop6irt.$(XOBJ) $(LIBOBJ) $(LLAPCK) -o gpop6irt

gpop6mrt : gpop6mrt.$(XOBJ) $(LIBROBJ)
	$(CPCMP) gpop6mrt.$(XOBJ) $(LIBROBJ) $(LLAPCK) -o gpop6mrt

gpop7ctr : gpop7ctr.$(XOBJ) $(LIBOBJ)
	$(CPCMP) gpop7ctr.$(XOBJ) $(LIBOBJ) $(LLAPCK) -o gpop7ctr

tstrate : tstrate.$(XOBJ) $(LIBTOBJ)
	$(CPCMP) tstrate.$(XOBJ) $(LIBTOBJ) $(LLAPCK) -o tstrate

introt : introt.$(XOBJ) $(LIBTOBJ)
	$(CPCMP) introt.$(XOBJ) $(LIBTOBJ) $(LLAPCK) -o introt

gpop1scf.$(XOBJ) : gpop1scf.cc gpop1scf.h $(HEADS)
	$(CPCMP) -c gpop1scf.cc

gpop3atm.$(XOBJ) : gpop3atm.cc $(HEADST)
	$(CPCMP) -c gpop3atm.cc

gpop3tst.$(XOBJ) : gpop3tst.cc $(HEADST)
	$(CPCMP) -c gpop3tst.cc

gpop4thf.$(XOBJ) : gpop4thf.cc $(HEADST)
	$(CPCMP) -c gpop4thf.cc

gpop5vib.$(XOBJ) : gpop5vib.cc $(HEADS)
	$(CPCMP) -c gpop5vib.cc

gpop6irt.$(XOBJ) : gpop6irt.cc $(HEADS)
	$(CPCMP) -c gpop6irt.cc

gpop6mrt.$(XOBJ) : gpop6mrt.cc $(HEADSR)
	$(CPCMP) -c gpop6mrt.cc

gpop7ctr.$(XOBJ) : gpop7ctr.cc $(HEADS)
	$(CPCMP) -c gpop7ctr.cc

tstrate.$(XOBJ) : tstrate.cc $(HEADST)
	$(CPCMP) -c tstrate.cc

introt.$(XOBJ) : introt.cc $(HEADST)
	$(CPCMP) -c introt.cc

gpoplibt.$(XOBJ) : gpoplibt.cc $(HEADST)
	$(CPCMP) -c gpoplibt.cc

gpoplibr.$(XOBJ) : gpoplibr.cc $(HEADSR)
	$(CPCMP) -c gpoplibr.cc

gpoplibc.$(XOBJ) : gpoplibc.cc $(HEADS)
	$(CPCMP) -c gpoplibc.cc

gpoplibf.$(XOBJ) : gpoplibf.cc gpoplibf.h
	$(CPCMP) -c gpoplibf.cc

lapack_dsyev.a : lapack_dsyev/*.f
	cd lapack_dsyev; \
	$(F7CMP) -c *.f; \
	ar cr ../$(FLPKSE) *.$(XOBJ); \
	$(RM) *.$(XOBJ); \
	cd ..

lapack_dsyev.lib : lapack_dsyev/*.f
	cd lapack_dsyev
	$(F7CMP) -c *.f
	lib /OUT:..\$(FLPKSE) *.$(XOBJ)
	$(RM) *.$(XOBJ)
	cd ..

clean:
	$(RM) *.$(XOBJ) $(FLPKSE) $(TMPF)

